bayespy.inference.vmp.nodes.multinomial.MultinomialMoments
==========================================================

.. currentmodule:: bayespy.inference.vmp.nodes.multinomial

.. autoclass:: MultinomialMoments

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~MultinomialMoments.add_converter
      ~MultinomialMoments.compute_dims_from_values
      ~MultinomialMoments.compute_fixed_moments
      ~MultinomialMoments.get_converter
   
   

   
   
   